pub fn validate_code_point(code_point: u32) -> Result<(), EastAsianWidthError>Expand description
Validates that the input is a valid Unicode code point
pub fn validate_code_point(code_point: u32) -> Result<(), EastAsianWidthError>Validates that the input is a valid Unicode code point